@@ -36,9 +36,9 @@ This module's methods are the following:
     :widths: 30, 70
     :delim: |
 
-    :meth:`~TwoGraph.is_regular_twograph` | tests if ``self`` is a regular two-graph, i.e. a 2-design
-    :meth:`~TwoGraph.complement` | returns the complement of ``self``
-    :meth:`~TwoGraph.descendant` | returns the descendant graph at `w`
+    :meth:`~TwoGraph.is_regular_twograph` | Test if ``self`` is a regular two-graph, i.e. a 2-design
+    :meth:`~TwoGraph.complement` | Return the complement of ``self``
+    :meth:`~TwoGraph.descendant` | Return the descendant graph at `w`
 
 This module's functions are the following:
 
@@ -47,9 +47,9 @@ This module's functions are the following:
     :widths: 30, 70
     :delim: |
 
-    :func:`~taylor_twograph` | constructs Taylor's two-graph for `U_3(q)`
-    :func:`~is_twograph`         | checks that the incidence system is a two-graph
-    :func:`~twograph_descendant`  | returns the descendant graph w.r.t. a given vertex of the two-graph of a given graph
+    :func:`~taylor_twograph` | Construct Taylor's two-graph for `U_3(q)`
+    :func:`~is_twograph`         | Check that the incidence system is a two-graph
+    :func:`~twograph_descendant`  | Return the descendant graph w.r.t. a given vertex of the two-graph of a given graph
 
 Methods
 ---------
@@ -68,12 +68,11 @@ class TwoGraph(IncidenceStructure):
     of size four contains an even number of elements of `T`. For more
     information, see the documentation of the
     :mod:`~sage.combinat.designs.twographs` module.
-
     """
     def __init__(self, points=None, blocks=None, incidence_matrix=None,
-            name=None, check=False, copy=True):
+                 name=None, check=False, copy=True):
         r"""
-        Constructor of the class
+        Constructor of the class.
 
         TESTS::
 
@@ -103,8 +102,8 @@ class TwoGraph(IncidenceStructure):
 
         INPUT:
 
-        - ``alpha`` -- (default: ``False``) return the value of
-          ``alpha``, if possible.
+        - ``alpha`` -- boolean (default: ``False``); return the value of
+          ``alpha``, if possible
 
         EXAMPLES::
 
@@ -127,7 +126,7 @@ class TwoGraph(IncidenceStructure):
 
     def descendant(self, v):
         """
-        The descendant :class:`graph <sage.graphs.graph.Graph>` at ``v``
+        The descendant :class:`graph <sage.graphs.graph.Graph>` at ``v``.
 
         The :mod:`switching class of graphs <sage.combinat.designs.twographs>`
         corresponding to ``self`` contains a graph ``D`` with ``v`` its own connected
@@ -150,7 +149,7 @@ class TwoGraph(IncidenceStructure):
 
     def complement(self):
         """
-        The two-graph which is the complement of ``self``
+        The two-graph which is the complement of ``self``.
 
         That is, the two-graph consisting exactly of triples not in ``self``.
         Note that this is different from :meth:`complement
@@ -175,7 +174,7 @@ class TwoGraph(IncidenceStructure):
 
 def taylor_twograph(q):
     r"""
-    constructing Taylor's two-graph for `U_3(q)`, `q` odd prime power
+    Constructing Taylor's two-graph for `U_3(q)`, `q` odd prime power.
 
     The Taylor's two-graph `T` has the `q^3+1` points of the projective plane over `F_{q^2}`
     singular w.r.t. the non-degenerate Hermitean form `S` preserved by `U_3(q)` as its ground set;
@@ -258,7 +257,7 @@ def is_twograph(T) -> bool:
 
 def twograph_descendant(G, v, name=None):
     r"""
-    Return the descendant graph w.r.t. vertex `v` of the two-graph of `G`
+    Return the descendant graph w.r.t. vertex `v` of the two-graph of `G`.
 
     In the :mod:`switching class <sage.combinat.designs.twographs>` of `G`,
     construct a graph `\Delta` with `v` an isolated vertex, and return the subgraph
@@ -272,7 +271,7 @@ def twograph_descendant(G, v, name=None):
 
     - ``v`` -- a vertex of ``G``
 
-    - ``name`` -- (default: ``None``); no name, otherwise derive from the construction
+    - ``name`` -- (default: ``None``) no name, otherwise derive from the construction
 
     EXAMPLES:
 
