@@ -68,10 +68,10 @@ class IntegerVectorsModPermutationGroup(UniqueRepresentation):
     INPUT:
 
     - ``G`` -- a permutation group
-    - ``sum`` -- (default: None) - a nonnegative integer
-    - ``max_part`` -- (default: None) - a nonnegative integer setting the
+    - ``sum`` -- (default: ``None``) - a nonnegative integer
+    - ``max_part`` -- (default: ``None``) - a nonnegative integer setting the
       maximum value for every element
-    - ``sgs`` -- (default: None) - a strong generating system of the
+    - ``sgs`` -- (default: ``None``) - a strong generating system of the
       group `G`. If you do not provide it, it will be calculated at the
       creation of the parent
 
@@ -243,7 +243,6 @@ class IntegerVectorsModPermutationGroup(UniqueRepresentation):
         792
         1287
         2002
-
     """
     @staticmethod
     def __classcall__(cls, G, sum=None, max_part=None, sgs=None):
@@ -417,7 +416,7 @@ class IntegerVectorsModPermutationGroup_All(UniqueRepresentation, RecursivelyEnu
 
     def roots(self):
         r"""
-        Returns the root of generation of ``self``. This method is
+        Return the root of generation of ``self``. This method is
         required to build the tree structure of ``self`` which
         inherits from the class :class:`~sage.sets.recursively_enumerated_set.RecursivelyEnumeratedSet_forest`.
 
@@ -431,7 +430,7 @@ class IntegerVectorsModPermutationGroup_All(UniqueRepresentation, RecursivelyEnu
 
     def children(self, x):
         r"""
-        Returns the list of children of the element ``x``. This method
+        Return the list of children of the element ``x``. This method
         is required to build the tree structure of ``self`` which
         inherits from the class :class:`~sage.sets.recursively_enumerated_set.RecursivelyEnumeratedSet_forest`.
 
@@ -445,7 +444,7 @@ class IntegerVectorsModPermutationGroup_All(UniqueRepresentation, RecursivelyEnu
 
     def permutation_group(self):
         r"""
-        Returns the permutation group given to define ``self``.
+        Return the permutation group given to define ``self``.
 
         EXAMPLES::
 
@@ -457,7 +456,7 @@ class IntegerVectorsModPermutationGroup_All(UniqueRepresentation, RecursivelyEnu
 
     def is_canonical(self, v, check=True):
         r"""
-        Returns ``True`` if the integer list ``v`` is maximal in its
+        Return ``True`` if the integer list ``v`` is maximal in its
         orbit under the action of the permutation group given to
         define ``self``.  Such integer vectors are said to be
         canonical. A vector `v` is canonical if and only if
@@ -508,7 +507,7 @@ class IntegerVectorsModPermutationGroup_All(UniqueRepresentation, RecursivelyEnu
 
     def __call__(self, v, check=True):
         r"""
-        Returns an element of ``self`` constructed from ``v`` if
+        Return an element of ``self`` constructed from ``v`` if
         possible.
 
         TESTS::
@@ -527,7 +526,7 @@ class IntegerVectorsModPermutationGroup_All(UniqueRepresentation, RecursivelyEnu
 
     def orbit(self, v):
         r"""
-        Returns the orbit of the integer vector ``v`` under the action of the
+        Return the orbit of the integer vector ``v`` under the action of the
         permutation group defining ``self``. The result is a set.
 
         EXAMPLES:
@@ -557,7 +556,7 @@ class IntegerVectorsModPermutationGroup_All(UniqueRepresentation, RecursivelyEnu
 
     def subset(self, sum=None, max_part=None):
         r"""
-        Returns the subset of ``self`` containing integer vectors
+        Return the subset of ``self`` containing integer vectors
         whose entries sum to ``sum``.
 
         EXAMPLES::
@@ -591,7 +590,7 @@ class IntegerVectorsModPermutationGroup_All(UniqueRepresentation, RecursivelyEnu
 
         def check(self):
             r"""
-            Checks that ``self`` verify the invariants needed for
+            Check that ``self`` verify the invariants needed for
             living in ``self.parent()``.
 
             EXAMPLES::
@@ -832,7 +831,6 @@ class IntegerVectorsModPermutationGroup_with_constraints(UniqueRepresentation, R
             sage: I = IntegerVectorsModPermutationGroup(G, sum=3)
             sage: list(iter(I))
             []
-
         """
         # Special cases when domain is empty.
         if self.n == 0:
@@ -945,7 +943,6 @@ class IntegerVectorsModPermutationGroup_with_constraints(UniqueRepresentation, R
             10
             sage: IntegerVectorsModPermutationGroup(T10, 100).cardinality()
             4263421511271
-
         """
         G = self._permgroup
         k = G.degree()          # Vector length
@@ -1129,7 +1126,7 @@ class IntegerVectorsModPermutationGroup_with_constraints(UniqueRepresentation, R
         r"""
         Return an element of ``self``.
 
-        Raises an :class:`EmptySetError` when ``self`` is empty.
+        Raises an :exc:`EmptySetError` when ``self`` is empty.
 
         EXAMPLES::
 
@@ -1178,7 +1175,7 @@ class IntegerVectorsModPermutationGroup_with_constraints(UniqueRepresentation, R
         INPUT:
 
         - ``v`` -- an element of ``self`` or any list of length the
-          degree of the permutation group.
+          degree of the permutation group
 
         EXAMPLES:
 
