@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+# sage.doctest: needs sage.combinat sage.modules
 r"""
 Kirillov-Reshetikhin Tableaux
 
@@ -62,6 +62,7 @@ from sage.combinat.crystals.kirillov_reshetikhin import horizontal_dominoes_remo
 from sage.combinat.partition import Partition
 from sage.combinat.tableau import Tableau
 
+
 class KirillovReshetikhinTableaux(CrystalOfWords):
     r"""
     Kirillov-Reshetikhin tableaux.
@@ -553,7 +554,7 @@ class KirillovReshetikhinTableaux(CrystalOfWords):
                 elif isinstance(B, KirillovReshetikhinTableaux):
                     dims.append([B._r, B._s])
             return TensorProductOfKirillovReshetikhinTableaux(ct, dims)
-        return super(KirillovReshetikhinTableaux, self).tensor(*crystals, **options)
+        return super().tensor(*crystals, **options)
 
     @lazy_attribute
     def _tableau_height(self):
@@ -568,6 +569,7 @@ class KirillovReshetikhinTableaux(CrystalOfWords):
         """
         return self._r
 
+
 class KRTableauxRectangle(KirillovReshetikhinTableaux):
     r"""
     Kirillov-Reshetkhin tableaux `B^{r,s}` whose module generator is a single
@@ -585,6 +587,7 @@ class KRTableauxRectangle(KirillovReshetikhinTableaux):
         sage: KRT = crystals.KirillovReshetikhin(['C', 3, 1], 3, 2, model='KR')
         sage: TestSuite(KRT).run() # long time
     """
+
     def _build_module_generators(self):
         r"""
         Build the module generators.
@@ -625,6 +628,7 @@ class KRTableauxRectangle(KirillovReshetikhinTableaux):
         f_str = reversed(krc.lift().to_highest_weight()[1])
         return self.module_generators[0].f_string(f_str)
 
+
 class KRTableauxTypeVertical(KirillovReshetikhinTableaux):
     r"""
     Kirillov-Reshetkihn tableaux `B^{r,s}` of type:
@@ -642,18 +646,17 @@ class KRTableauxTypeVertical(KirillovReshetikhinTableaux):
         sage: KRT = crystals.KirillovReshetikhin(['A', 5, 2], 2, 2, model='KR')
         sage: TestSuite(KRT).run() # long time
     """
+
     def _fill(self, weight):
         r"""
         Return the highest weight KR tableau of weight ``weight``.
 
         INPUT:
 
-        - ``weight`` -- The weight of the highest weight KR tableau (the
+        - ``weight`` -- the weight of the highest weight KR tableau (the
           conjugate of the shape of the KR crystal's tableau)
 
-        OUTPUT:
-
-        - A `r \times s` tableau
+        OUTPUT: a `r \times s` tableau
 
         EXAMPLES::
 
@@ -754,6 +757,7 @@ class KRTableauxTypeVertical(KirillovReshetikhinTableaux):
         f_str = reversed(lifted.to_highest_weight()[1])
         return self._fill(weight).f_string(f_str)
 
+
 class KRTableauxTypeHorizonal(KirillovReshetikhinTableaux):
     r"""
     Kirillov-Reshetikhin tableaux `B^{r,s}` of type:
@@ -768,17 +772,16 @@ class KRTableauxTypeHorizonal(KirillovReshetikhinTableaux):
         sage: KRT = crystals.KirillovReshetikhin(CartanType(['A', 4, 2]).dual(), 2, 2, model='KR')
         sage: TestSuite(KRT).run()
     """
+
     def _fill(self, shape):
         r"""
         Return the highest weight KR tableau of weight ``shape``.
 
         INPUT:
 
-        - ``shape`` -- The shape of the KR crystal's tableau
+        - ``shape`` -- the shape of the KR crystal's tableau
 
-        OUTPUT:
-
-        - A `r \times s` tableau
+        OUTPUT: a `r \times s` tableau
 
         EXAMPLES::
 
@@ -797,17 +800,17 @@ class KRTableauxTypeHorizonal(KirillovReshetikhinTableaux):
             shape_list.append(0)
 
         lst = []
-        for col in range(1, self._s+1):
+        for col in range(1, self._s + 1):
             if (self._s - col) % 2 == 0:
-                lst.extend( [self.letters(self._r - x) for x in range(self._r)] )
+                lst.extend(self.letters(self._r - x) for x in range(self._r))
             else:
                 m = self._r
                 for j, val in enumerate(shape_list):
                     if col >= val:
                         m = j
                         break
-                lst.extend([self.letters(-x) for x in range(m+1, self._r+1)])
-                lst.extend([self.letters(m - x) for x in range(m)])
+                lst.extend(self.letters(-x) for x in range(m + 1, self._r + 1))
+                lst.extend(self.letters(m - x) for x in range(m))
 
         return self.element_class(self, lst)
 
@@ -847,6 +850,7 @@ class KRTableauxTypeHorizonal(KirillovReshetikhinTableaux):
         f_str = reversed(lifted.to_highest_weight()[1])
         return self._fill(shape).f_string(f_str)
 
+
 class KRTableauxTypeBox(KRTableauxTypeVertical):
     r"""
     Kirillov-Reshetikhin tableaux `B^{r,s}` of type:
@@ -864,18 +868,17 @@ class KRTableauxTypeBox(KRTableauxTypeVertical):
         sage: KRT = crystals.KirillovReshetikhin(['D', 4, 3], 1, 2, model='KR')
         sage: TestSuite(KRT).run() # long time
     """
+
     def _fill(self, weight):
         r"""
         Return the highest weight KR tableau of weight ``weight``.
 
         INPUT:
 
-        - ``weight`` -- The weight of the highest weight KR tableau (the
+        - ``weight`` -- the weight of the highest weight KR tableau (the
           conjugate of the shape of the KR crystal's tableau)
 
-        OUTPUT:
-
-        - A `r \times s` tableau
+        OUTPUT: a `r \times s` tableau
 
         EXAMPLES::
 
@@ -951,6 +954,7 @@ class KRTableauxTypeBox(KRTableauxTypeVertical):
         """
         return tuple(self._fill(weight) for weight in partitions_in_box(self._s, self._r))
 
+
 class KRTableauxSpin(KRTableauxRectangle):
     r"""
     Kirillov-Reshetikhin tableaux `B^{r,s}` of type `D_n^{(1)}` with
@@ -963,6 +967,7 @@ class KRTableauxSpin(KRTableauxRectangle):
         sage: KRT = crystals.KirillovReshetikhin(['D', 4, 1], 4, 2, model='KR')
         sage: TestSuite(KRT).run()
     """
+
     def _build_module_generators(self):
         r"""
         Build the module generators.
@@ -989,6 +994,7 @@ class KRTableauxSpin(KRTableauxRectangle):
 
         return (self.element_class(self, [self.letters(x) for x in flatten(tableau)]),)
 
+
 class KRTableauxBn(KRTableauxTypeHorizonal):
     """
     Kirillov-Reshetkhin tableaux `B^{n,s}` of type `B_n^{(1)}`.
@@ -998,6 +1004,7 @@ class KRTableauxBn(KRTableauxTypeHorizonal):
         sage: KRT = crystals.KirillovReshetikhin(['B', 2, 1], 2, 3, model='KR')
         sage: TestSuite(KRT).run()
     """
+
     def _build_module_generators(self):
         """
         Build the module generators.
@@ -1040,6 +1047,7 @@ class KRTableauxBn(KRTableauxTypeHorizonal):
                 return x.f_string(f_str)
         raise ValueError("no matching highest weight element found")
 
+
 class KirillovReshetikhinTableauxElement(TensorProductOfRegularCrystalsElement):
     r"""
     A Kirillov-Reshetikhin tableau.
@@ -1049,6 +1057,7 @@ class KirillovReshetikhinTableauxElement(TensorProductOfRegularCrystalsElement):
     and
     :class:`~sage.combinat.rigged_configurations.tensor_product_kr_tableaux.TensorProductOfKirillovReshetikhinTableaux`.
     """
+
     def __init__(self, parent, list, **options):
         r"""
         Initialize ``self``.
@@ -1204,8 +1213,8 @@ class KirillovReshetikhinTableauxElement(TensorProductOfRegularCrystalsElement):
 
         INPUT:
 
-        - ``rows`` -- (Default: ``True``) Set to ``True`` if the resulting
-          array is by row, otherwise it is by column.
+        - ``rows`` -- boolean (default: ``True``); set to ``True`` if the
+          resulting array is by row, otherwise it is by column
 
         EXAMPLES::
 
@@ -1272,9 +1281,9 @@ class KirillovReshetikhinTableauxElement(TensorProductOfRegularCrystalsElement):
 
         INPUT:
 
-        - ``index_set`` -- (Default: ``None``) Return the highest weight
-          with respect to the index set. If ``None`` is passed in, then this
-          uses the classical index set.
+        - ``index_set`` -- (default: ``None``) return the highest weight
+          with respect to the index set; if ``None`` is passed in, then this
+          uses the classical index set
 
         OUTPUT:
 
@@ -1459,8 +1468,10 @@ class KirillovReshetikhinTableauxElement(TensorProductOfRegularCrystalsElement):
         """
         return self.lusztig_involution().left_split().lusztig_involution()
 
+
 KirillovReshetikhinTableaux.Element = KirillovReshetikhinTableauxElement
 
+
 class KRTableauxSpinElement(KirillovReshetikhinTableauxElement):
     r"""
     Kirillov-Reshetikhin tableau for spinors.
@@ -1470,6 +1481,7 @@ class KRTableauxSpinElement(KirillovReshetikhinTableauxElement):
     respectively for all `i \neq 0`. We do this so our columns are full
     width (as opposed to half width and/or uses a `\pm` representation).
     """
+
     def e(self, i):
         r"""
         Calculate the action of `e_i` on ``self``.
@@ -1571,8 +1583,8 @@ class KRTableauxSpinElement(KirillovReshetikhinTableauxElement):
 
         INPUT:
 
-        - ``rows`` -- (Default: ``True``) Set to ``True`` if the resulting
-          array is by row, otherwise it is by column.
+        - ``rows`` -- boolean (default: ``True``); set to ``True`` if the
+          resulting array is by row, otherwise it is by column
 
         EXAMPLES::
 
@@ -1650,9 +1662,11 @@ class KRTableauxSpinElement(KirillovReshetikhinTableauxElement):
             WLR = F.ambient_space()
         return sum((self[j].weight() for j in range(len(self))), WLR.zero()) / 2
 
+
 KRTableauxBn.Element = KRTableauxSpinElement
 KRTableauxSpin.Element = KRTableauxSpinElement
 
+
 class KRTableauxDTwistedSpin(KRTableauxRectangle):
     r"""
     Kirillov-Reshetikhin tableaux `B^{r,s}` of type `D_n^{(2)}` with `r = n`.
@@ -1668,11 +1682,13 @@ class KRTableauxDTwistedSpin(KRTableauxRectangle):
     """
     Element = KRTableauxSpinElement
 
+
 class KRTableauxTypeFromRCElement(KirillovReshetikhinTableauxElement):
     r"""
     A Kirillov-Reshetikhin tableau constructed from rigged configurations
     under the bijection `\Phi`.
     """
+
     def e(self, i):
         """
         Perform the action of `e_i` on ``self``.
@@ -1787,6 +1803,7 @@ class KRTableauxTypeFromRC(KirillovReshetikhinTableaux):
         non-trivial multiplicities of classical components, so
         :meth:`classical_decomposition` does not work.
     """
+
     def __init__(self, cartan_type, r, s):
         r"""
         Initialize ``self``.
